@@ -149,6 +149,12 @@ class Module:
             widget = GSettingsComboBox(_("Keyboard layout"), "org.cinnamon.keyboard", "keyboard-type", keyboard_type_options)
             settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
 
+            activation_mode_options = [["accessible", _("Show the keyboard any time something expects input")],
+                                       ["on-demand",  _("Show keyboard only when the user activates it")]];
+
+            widget = GSettingsComboBox(_("Activation mode"), "org.cinnamon.keyboard", "activation-mode", activation_mode_options)
+            settings.add_reveal_row(widget, "org.cinnamon.desktop.a11y.applications", "screen-keyboard-enabled")
+
 # Keyboard indicators
 
             settings = page.add_section(_("Keyboard indicators"))
